@@ -8,6 +8,9 @@
 #include "dictionary.h"
 #include "layoutmanager.h"
 #include "textprocessor.h"
+#include "phonebook.h"
+
+
 
 namespace Ui {
     class Fastsms;
@@ -39,11 +42,15 @@ private:
     QDialog *m_dialNewWord;
     QLineEdit *m_inputNewWord;
     bool m_bDictionaryUpdated;
+//    PhoneBook *m_phonebook;
+
+
 
 private slots:
     void saveDictionaryOnExit();
     void newWordInserted();
     void composite(QString,Core::Keyboards);
+//    void openPhoneBook();
 
 protected:
     bool registerService();
