@@ -4,6 +4,7 @@
 #include <QWidget>
 #include <QLineEdit>
 #include <QPushButton>
+#include "phonebook.h"
 
 namespace Ui {
     class Recipient;
@@ -19,12 +20,17 @@ public:
     QLineEdit* getPhoneNumberField();
     QPushButton *m_btSend;
     bool sendSMS(QString sMessage);
-    bool addRecipient(const QString &phone, const QString &name);
+
 
 private:
-    Ui::Recipient *ui;    
+    Ui::Recipient *ui;
+    PhoneBook *m_phonebook;
+
+public slots:
+     bool addRecipient(const QString &phone, const QString &name);
 
 private slots:
+    void displayPhoneBook(QString sText);
     void openPhoneBook();
 };
 
